<?php

/**
 * Plugin Name: CiberProtector — Protección 2FA + VPN
 * Plugin URI:  https://ciberprotector.com
 * Description: Autenticación en dos pasos para WordPress + Protección Conexión Segura CiberProtector.
 * Version:     0.0.4
 * Author: 	    webempresa.com
 * Author:      Two Factor Authentication Service Inc.
 * Author URI:  https://ciberprotector.com
 * License:     GPL2
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

defined('ABSPATH') or die();

require_once plugin_dir_path(__FILE__) . 'global_class_loader.php';


define('CIBERPROTECTOR_PLUGIN_PATH', plugins_url() . DIRECTORY_SEPARATOR . dirname(plugin_basename(__FILE__)));
define('CIBERPROTECTOR_WP_ADMIN_PATH', get_admin_url());
define('CIBERPROTECTOR_PLUGIN_VERSION', '1.1.3');

ciberprotector_bind_enqueue_styles();
ciberprotector_check_system_requirements_and_init();

function ciberprotector_bind_enqueue_styles()
{
	add_action('login_enqueue_scripts', 'ciberprotector_enqueue_styles');
	add_action('admin_enqueue_scripts', 'ciberprotector_enqueue_styles');
}

function ciberprotector_enqueue_styles()
{
	wp_enqueue_style(
		'ciberprotector',
		CIBERPROTECTOR_PLUGIN_PATH . '/includes/css/ciberprotector.css',
		array(),
		CIBERPROTECTOR_PLUGIN_VERSION
	);
	wp_enqueue_style('roboto', 'https://fonts.googleapis.com/css?family=Roboto');
}

function ciberprotector_check_system_requirements_and_init()
{
	$versions_provider = new ciberprotector_System_Versions_Provider();
	$requirements_spec = new ciberprotector_Requirements_Spec('5.3', '3.6', array('gd', 'mbstring', 'openssl'));
	$system_requirements = new ciberprotector_System_Requirements_Checker($versions_provider, $requirements_spec);

	try {
		$system_requirements->check_system_requirements();
	} catch (ciberprotector_Unmet_System_Requirements_Exception $e) {
		ciberprotector_enqueue_unmet_requirements_error($e);
		ciberprotector_enqueue_unmet_requirements_login_prevention();
		return;
	}

	require 'ciberprotector_init.php';
	ciberprotector_bind_to_wp_hooks();
}

function ciberprotector_enqueue_unmet_requirements_error(ciberprotector_Unmet_System_Requirements_Exception $e)
{
	$error_printer = new ciberprotector_Unmet_Requirements_Error_Printer($e);
	add_action('admin_notices', array($error_printer, 'print_error'));
}

function ciberprotector_enqueue_unmet_requirements_login_prevention()
{
	if (defined('CIBERPROTECTOR_FULL_TWOFAS_PLUGIN_ACTIVE_FLAG')) {
		return;
	}

	$login_preventer_setup = new ciberprotector_Login_Preventer_Setup();
	$login_preventer_setup->bind_to_hooks();
}






/*
*	Custom upgrades
*/


function wpciber_plugins_api_result( $res, $action, $args) {


   if ( $action == 'plugin_information' ) {


        if ( isset( $args->slug ) && $args->slug == plugin_basename( __FILE__ ) ) {

            $info = json_decode(file_get_contents("https://optimizador.io/pluginupdates-wpciberprotector.json") ) ;



            $res = (object) array(
                'name' => $info->name,
                'version' => $info->version ,
                'slug' => $args->slug,
                'download_link' => $info->download_url ,

                'tested' => $info->tested,
                'requires' => $info->requires,
                'last_updated' => $info->last_updated,
                'homepage' => $info->homepage,
                'sections' => array( 'description' => $info->sections->description, 'installation' => $info->sections->installation , 'changelog' => $info->sections->changelog ) ,
                'banners' => array(
                    'low' => $info->banners->low,
                    'high' => $info->banners->high
                ),

                'external' => true
            );
            //if ( 1 == 2 ) {
            //    $res['sections']['changelog'] = "Changelog";
            //}
            return $res;
            //return false;
        }
    }
    return $res;

}

add_filter( 'plugins_api_result', 'wpciber_plugins_api_result' , 10, 3  );

function wpciber_check_for_update($transient ) {


    if ( empty( $transient->checked ) ) {
        return $transient;
    }



	if ( !function_exists("plugin_basename") ){
		return $transient;
	}


	//
	// Mejor no usamos get_plugin_data para evitar problemas
	//
	// $plugin_data = get_plugin_data( __FILE__ );
	// $plugin_version = $plugin_data['Version'];

	$plugin_version = "0.0.3";

	$salidaTXT = file_get_contents("https://optimizador.io/pluginupdates-wpciberprotector.json");


	$info = json_decode( $salidaTXT ) ;



	  if (  version_compare( $plugin_version , $info->version, '<') ) {



            $plugin_slug = plugin_basename( __FILE__ );

            $transient->response[$plugin_slug] = (object) array(
                'new_version' => $info->version ,
                'package' => $info->download_url,
                'slug' => $plugin_slug
            );
    }



    return $transient;
}

add_filter( 'pre_set_site_transient_update_plugins', 'wpciber_check_for_update'  );


function wpciber_plugins_api_handler($res, $action, $args ) {
    if ( $action == 'plugin_information' ) {


        if ( isset( $args->slug ) && $args->slug == plugin_basename( __FILE__ ) ) {

			$info = json_decode(file_get_contents("https://optimizador.io/pluginupdates-wpciberprotector.json") ) ;



            $res = (object) array(
                'name' => $info->name,
                'version' => $info->version ,
                'slug' => $args->slug,
                'download_link' => $info->download_url ,

                'tested' => $info->tested,
                'requires' => $info->requires,
                'last_updated' => $info->last_updated,
                'homepage' => $info->homepage,
				'sections' => array( 'description' => $info->sections->description, 'installation' => $info->sections->installation , 'changelog' => $info->sections->changelog ) ,
                'banners' => array(
                    'low' => $info->banners->low,
                    'high' => $info->banners->high
                ),

                'external' => true
            );
            //if ( 1 == 2 ) {
            //    $res['sections']['changelog'] = "Changelog";
            //}
		    //return apply_filters( 'plugins_api_result', $res, $action, $args );
            return $res;
			//return false;
        }
    }
    return false;
}


add_filter( 'plugins_api', 'wpciber_plugins_api_handler' , 10, 3 );
