<?php

namespace TwoFAS\Light;

use TwoFAS\Light\Action\Authenticate;
use TwoFAS\Light\Exception\ciberprotector_Exception;
use TwoFAS\Light\Request\Regular_Request;
use TwoFAS\Light\Result\Error_Consumer;
use TwoFAS\Light\Result\HTML_Consumer;
use TwoFAS\Light\Result\User_Consumer;

class Authenticate_App extends App implements HTML_Consumer, User_Consumer, Error_Consumer
{

	/** @var Authenticate */
	private $action;

	/**
	 * Authenticate_App constructor.
	 *
	 * @param Authenticate $action
	 */
	public function __construct(Authenticate $action)
	{
		parent::__construct();
		$this->action = $action;
	}

	public function run()
	{
		$this->request = new Regular_Request();
		$this->request->fill_with_context($this->request_context);

		$result = $this->action->handle($this);

		if (!$result) {
			return null;
		}

		return $result->feed_consumer($this);
	}

	/**
	 * @param $user_id
	 *
	 * @return \WP_User
	 */
	public function consume_user($user_id)
	{
		return new \WP_User($user_id);
	}

	/**
	 * @param $html
	 */
	public function consume_html($html)
	{
		echo $html;
		exit();
	}

	/**
	 * @param $error
	 *
	 * @return mixed
	 * @throws \Exception
	 */
	public function consume_error($error)
	{
		if (!is_a($error, '\WP_Error')) {
			throw new ciberprotector_Exception('Unexpected response type from request handler');
		}

		return $error;
	}
}
